pub struct Scales {
pub ren: ScaleFuncForm,
pub fac: ScaleFuncForm,
pub frg: ScaleFuncForm,
}Expand description
Instances of this type define how the renormalization, factorization and fragmentation scales are calculated.
Fields
ren: ScaleFuncFormThe renormalization scale used by the strong coupling.
fac: ScaleFuncFormThe factorization scale used by parton distribution functions.
frg: ScaleFuncFormThe fragmentation scale used by fragmentation functions.
Implementations
Sourceimpl Scales
impl Scales
Sourcepub fn compatible_with(&self, kinematics: &[Kinematics]) -> bool
pub fn compatible_with(&self, kinematics: &[Kinematics]) -> bool
Return true if these scale definitions are compatible with kinematics.
A scale definition is compatible if every ScaleFuncForm refers only to scale-type
kinematic variables that are present in kinematics.