Module evolution

Supporting classes and functions for Grid::evolve.

Structs

AlphasTable
A mapping of squared renormalization scales in ren1 to strong couplings in alphas. The ordering of both members defines the mapping.
EvolveInfo
This structure captures the information needed to create an evolution kernel operator (EKO) for a specific Grid.
OperatorSliceInfo
Information about the evolution kernel operator slice (EKO) passed to Grid::evolve as operator, which is used to convert a Grid into an FkTable. The dimensions of the EKO must correspond to the values given in fac1, pids0, x0, pids1 and x1, exactly in this order. Members with a 1 are defined at the squared factorization scale given as fac1 (often called process scale) and are found in the Grid that Grid::evolve is called with. Members with a 0 are defined at the squared factorization scale fac0 (often called fitting scale or starting scale) and are found in the FkTable resulting from Grid::evolve.