Module pids

Module pids 

Particle ID basis handling, charge conjugation, and channel translation for FK evolution.

Structs

OptRules
Return type of PidBasis::opt_rules.

Enums

PidBasis
Particle ID bases. In PineAPPL every particle is identified using a particle identifier (PID), which is represented as an i32. The values of this enum specify how this value is interpreted.

Functions

charge_conjugate_pdg_pid
Return the charge-conjugated PDG ID of pid.
pdg_mc_ids_to_evol
Given tuples representing a linear combination of PDG MC IDs.