Module pineappl::evolution

source ·
Supporting classes and functions for Grid::evolve.

Structs

  • This structure captures the information needed to create an evolution kernel operator (EKO) for a specific Grid.
  • Information about the evolution kernel operator (EKO) passed to Grid::evolve as operator, which is used to convert a Grid into an FkTable. The dimensions of the EKO must correspond to the values given in fac1, pids0, x0, pids1 and x1, exactly in this order. Members with a 1 are defined at the squared factorization scales given in fac1 (often called process scales) and are found in the Grid that Grid::evolve is called with. Members with a 0 are defined at the squared factorization scale fac0 (often called fitting scale or starting scale) and are found in the FkTable resulting from Grid::evolve.