Supporting classes and functions for Grid::evolve.
Structs
- This structure captures the information needed to create an evolution kernel operator (EKO) for a specific
Grid. - Information about the evolution kernel operator (EKO) passed to
Grid::evolveasoperator, which is used to convert aGridinto anFkTable. The dimensions of the EKO must correspond to the values given infac1,pids0,x0,pids1andx1, exactly in this order. Members with a1are defined at the squared factorization scales given infac1(often called process scales) and are found in theGridthatGrid::evolveis called with. Members with a0are defined at the squared factorization scalefac0(often called fitting scale or starting scale) and are found in theFkTableresulting fromGrid::evolve.