Provides the FkTable type.
Structs
- FkTable
- Structure implementing FK tables. These are special
Grids, for which the following additional guarantees are given:
Enums
- FkAssumptions
- The optimization assumptions for an
FkTable, needed forFkTable::optimize. Since FK tables are typically stored at very smallQ2 = Q0, the PDFsf(x,Q0)of heavy quarks are typically set to zero at this scale or set to the same value as their anti-quark PDF. This is used to optimize the size of FK tables.